==> apache-seata-2.4.0-incubating-src.tar.gz: apache-seata-2.4.0-incubating-src/saga/seata-saga-engine/src/main/java/org/apache/seata/saga/engine/exception/ForwardInvalidException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.saga.engine.exception;

import org.apache.seata.common.exception.FrameworkErrorCode;

/**
 * Forward operation invalid exception
 *
 */
public class ForwardInvalidException extends EngineExecutionException {

    public ForwardInvalidException() {
    }

    public ForwardInvalidException(FrameworkErrorCode err) {
        super(err);
    }

    public ForwardInvalidException(String msg) {
        super(msg);
    }

    public ForwardInvalidException(String msg, FrameworkErrorCode errCode) {
        super(msg, errCode);
    }

    public ForwardInvalidException(Throwable cause, String msg, FrameworkErrorCode errCode) {
        super(cause, msg, errCode);
    }

    public ForwardInvalidException(Throwable th) {
        super(th);
    }

    public ForwardInvalidException(Throwable th, String msg) {
        super(th, msg);
    }
}

==> apache-seata-2.6.0-incubating-src.tar.gz: apache-seata-2.6.0-incubating-src/saga/seata-saga-engine/src/main/java/org/apache/seata/saga/engine/exception/ForwardInvalidException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.saga.engine.exception;

import org.apache.seata.common.exception.FrameworkErrorCode;

/**
 * Forward operation invalid exception
 *
 */
public class ForwardInvalidException extends EngineExecutionException {

    public ForwardInvalidException() {}

    public ForwardInvalidException(FrameworkErrorCode err) {
        super(err);
    }

    public ForwardInvalidException(String msg) {
        super(msg);
    }

    public ForwardInvalidException(String msg, FrameworkErrorCode errCode) {
        super(msg, errCode);
    }

    public ForwardInvalidException(Throwable cause, String msg, FrameworkErrorCode errCode) {
        super(cause, msg, errCode);
    }

    public ForwardInvalidException(Throwable th) {
        super(th);
    }

    public ForwardInvalidException(Throwable th, String msg) {
        super(th, msg);
    }
}
